==> estateplat-common-1.1.0-20170206.095250-258-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjQszdDcb.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: sc 权属宗地调查表
 * Date: 15-4-23
 * Time: 下午4:56
 * To change this template use File | Settings | File Templates.
 */

public class DjsjQszdDcb {
    private String bdclxxx;
    private Date zzrq;
    private String gmjjhyfldm;
    private String blc;
    private Date jlrq;
    private Double pzmj;
    private String pzyt;
    private String tdyt;
    private String tdyt2;
    private String tdyt3;
    private String syqx;
    private String xzqmc;
    private String sztfh;
    private String bz;
    private Double fzmj;
    private Date gxrq;
    private String zldwdm;
    private String qsdwdm;
    private String qsxz;
    private String ybdjh;
    private String tdzl;
    private String zdsmj;
    private Double scmj;
    private String djh;
    private String ydjh;
    private String qszdDjdcbIndex;
    private String bdcdyh;
    private String dclx;
    private String qlsdfs;
    private String lyqlbh;
    private String zdsz;
    private String bdcdyhzt;
    private String gysyqqk;
    private String tdsyzmc;
    private String qslx;
    private String mjdw;

    public String getBdclxxx() {
        return bdclxxx;
    }

    public void setBdclxxx(String bdclxxx) {
        this.bdclxxx = bdclxxx;
    }

    public Date getZzrq() {
        return zzrq;
    }

    public void setZzrq(Date zzrq) {
        this.zzrq = zzrq;
    }

    public String getGmjjhyfldm() {
        return gmjjhyfldm;
    }

    public void setGmjjhyfldm(String gmjjhyfldm) {
        this.gmjjhyfldm = gmjjhyfldm;
    }

    public String getBlc() {
        return blc;
    }

    public void setBlc(String blc) {
        this.blc = blc;
    }

    public Date getJlrq() {
        return jlrq;
    }

    public void setJlrq(Date jlrq) {
        this.jlrq = jlrq;
    }

    public Double getPzmj() {
        return pzmj;
    }

    public void setPzmj(Double pzmj) {
        this.pzmj = pzmj;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getSyqx() {
        return syqx;
    }

    public void setSyqx(String syqx) {
        this.syqx = syqx;
    }

    public String getXzqmc() {
        return xzqmc;
    }

    public void setXzqmc(String xzqmc) {
        this.xzqmc = xzqmc;
    }

    public String getSztfh() {
        return sztfh;
    }

    public void setSztfh(String sztfh) {
        this.sztfh = sztfh;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Double getFzmj() {
        return fzmj;
    }

    public void setFzmj(Double fzmj) {
        this.fzmj = fzmj;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getZldwdm() {
        return zldwdm;
    }

    public void setZldwdm(String zldwdm) {
        this.zldwdm = zldwdm;
    }

    public String getQsdwdm() {
        return qsdwdm;
    }

    public void setQsdwdm(String qsdwdm) {
        this.qsdwdm = qsdwdm;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getYbdjh() {
        return ybdjh;
    }

    public void setYbdjh(String ybdjh) {
        this.ybdjh = ybdjh;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public String getZdsmj() {
        return zdsmj;
    }

    public void setZdsmj(String zdsmj) {
        this.zdsmj = zdsmj;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getYdjh() {
        return ydjh;
    }

    public void setYdjh(String ydjh) {
        this.ydjh = ydjh;
    }

    public String getQszdDjdcbIndex() {
        return qszdDjdcbIndex;
    }

    public void setQszdDjdcbIndex(String qszdDjdcbIndex) {
        this.qszdDjdcbIndex = qszdDjdcbIndex;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getDclx() {
        return dclx;
    }

    public void setDclx(String dclx) {
        this.dclx = dclx;
    }

    public String getQlsdfs() {
        return qlsdfs;
    }

    public void setQlsdfs(String qlsdfs) {
        this.qlsdfs = qlsdfs;
    }

    public String getLyqlbh() {
        return lyqlbh;
    }

    public void setLyqlbh(String lyqlbh) {
        this.lyqlbh = lyqlbh;
    }

    public String getZdsz() {
        return zdsz;
    }

    public void setZdsz(String zdsz) {
        this.zdsz = zdsz;
    }

    public String getBdcdyhzt() {
        return bdcdyhzt;
    }

    public void setBdcdyhzt(String bdcdyhzt) {
        this.bdcdyhzt = bdcdyhzt;
    }

    public String getGysyqqk() {
        return gysyqqk;
    }

    public void setGysyqqk(String gysyqqk) {
        this.gysyqqk = gysyqqk;
    }

    public String getTdsyzmc() {
        return tdsyzmc;
    }

    public void setTdsyzmc(String tdsyzmc) {
        this.tdsyzmc = tdsyzmc;
    }

    public String getQslx() {
        return qslx;
    }

    public void setQslx(String qslx) {
        this.qslx = qslx;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getTdyt2() {
        return tdyt2;
    }

    public void setTdyt2(String tdyt2) {
        this.tdyt2 = tdyt2;
    }

    public String getTdyt3() {
        return tdyt3;
    }

    public void setTdyt3(String tdyt3) {
        this.tdyt3 = tdyt3;
    }
}

==> estateplat-common-1.2.4-20210615.025653-792-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjQszdDcb.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * Created by IntelliJ IDEA.
 * User: sc 权属宗地调查表
 * Date: 15-4-23
 * Time: 下午4:56
 * To change this template use File | Settings | File Templates.
 */

public class DjsjQszdDcb {
    private String bdclxxx;
    private Date zzrq;
    private String gmjjhyfldm;
    private String blc;
    private Date jlrq;
    private Double pzmj;
    private String pzyt;
    private String tdyt;
    private String tdyt2;
    private String tdyt3;
    private String syqx;
    private String xzqmc;
    private String sztfh;
    private String bz;
    private Double fzmj;
    private Date gxrq;
    private String zldwdm;
    private String qsdwdm;
    private String qsxz;
    private String ybdjh;
    private String tdzl;
    private String zdsmj;
    private Double scmj;
    private String djh;
    private String ydjh;
    private String qszdDjdcbIndex;
    private String bdcdyh;
    private String dclx;
    private String qlsdfs;
    private String lyqlbh;
    private String zdsz;
    private String bdcdyhzt;
    private String gysyqqk;
    private String tdsyzmc;
    private String qslx;
    private String mjdw;
    private String syqlx;
    private Date qsrq;

    public String getBdclxxx() {
        return bdclxxx;
    }

    public void setBdclxxx(String bdclxxx) {
        this.bdclxxx = bdclxxx;
    }

    public Date getZzrq() {
        return zzrq;
    }

    public void setZzrq(Date zzrq) {
        this.zzrq = zzrq;
    }

    public String getGmjjhyfldm() {
        return gmjjhyfldm;
    }

    public void setGmjjhyfldm(String gmjjhyfldm) {
        this.gmjjhyfldm = gmjjhyfldm;
    }

    public String getBlc() {
        return blc;
    }

    public void setBlc(String blc) {
        this.blc = blc;
    }

    public Date getJlrq() {
        return jlrq;
    }

    public void setJlrq(Date jlrq) {
        this.jlrq = jlrq;
    }

    public Double getPzmj() {
        return pzmj;
    }

    public void setPzmj(Double pzmj) {
        this.pzmj = pzmj;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getSyqx() {
        return syqx;
    }

    public void setSyqx(String syqx) {
        this.syqx = syqx;
    }

    public String getXzqmc() {
        return xzqmc;
    }

    public void setXzqmc(String xzqmc) {
        this.xzqmc = xzqmc;
    }

    public String getSztfh() {
        return sztfh;
    }

    public void setSztfh(String sztfh) {
        this.sztfh = sztfh;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Double getFzmj() {
        return fzmj;
    }

    public void setFzmj(Double fzmj) {
        this.fzmj = fzmj;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getZldwdm() {
        return zldwdm;
    }

    public void setZldwdm(String zldwdm) {
        this.zldwdm = zldwdm;
    }

    public String getQsdwdm() {
        return qsdwdm;
    }

    public void setQsdwdm(String qsdwdm) {
        this.qsdwdm = qsdwdm;
    }

    public String getQsxz() {
        return qsxz;
    }

    public void setQsxz(String qsxz) {
        this.qsxz = qsxz;
    }

    public String getYbdjh() {
        return ybdjh;
    }

    public void setYbdjh(String ybdjh) {
        this.ybdjh = ybdjh;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public String getZdsmj() {
        return zdsmj;
    }

    public void setZdsmj(String zdsmj) {
        this.zdsmj = zdsmj;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getYdjh() {
        return ydjh;
    }

    public void setYdjh(String ydjh) {
        this.ydjh = ydjh;
    }

    public String getQszdDjdcbIndex() {
        return qszdDjdcbIndex;
    }

    public void setQszdDjdcbIndex(String qszdDjdcbIndex) {
        this.qszdDjdcbIndex = qszdDjdcbIndex;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getDclx() {
        return dclx;
    }

    public void setDclx(String dclx) {
        this.dclx = dclx;
    }

    public String getQlsdfs() {
        return qlsdfs;
    }

    public void setQlsdfs(String qlsdfs) {
        this.qlsdfs = qlsdfs;
    }

    public String getLyqlbh() {
        return lyqlbh;
    }

    public void setLyqlbh(String lyqlbh) {
        this.lyqlbh = lyqlbh;
    }

    public String getZdsz() {
        return zdsz;
    }

    public void setZdsz(String zdsz) {
        this.zdsz = zdsz;
    }

    public String getBdcdyhzt() {
        return bdcdyhzt;
    }

    public void setBdcdyhzt(String bdcdyhzt) {
        this.bdcdyhzt = bdcdyhzt;
    }

    public String getGysyqqk() {
        return gysyqqk;
    }

    public void setGysyqqk(String gysyqqk) {
        this.gysyqqk = gysyqqk;
    }

    public String getTdsyzmc() {
        return tdsyzmc;
    }

    public void setTdsyzmc(String tdsyzmc) {
        this.tdsyzmc = tdsyzmc;
    }

    public String getQslx() {
        return qslx;
    }

    public void setQslx(String qslx) {
        this.qslx = qslx;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getTdyt2() {
        return tdyt2;
    }

    public void setTdyt2(String tdyt2) {
        this.tdyt2 = tdyt2;
    }

    public String getTdyt3() {
        return tdyt3;
    }

    public void setTdyt3(String tdyt3) {
        this.tdyt3 = tdyt3;
    }

    public String getSyqlx() {
        return syqlx;
    }

    public void setSyqlx(String syqlx) {
        this.syqlx = syqlx;
    }

    public Date getQsrq() {
        return qsrq;
    }

    public void setQsrq(Date qsrq) {
        this.qsrq = qsrq;
    }
}
